@@ -21,6 +21,9 @@ from .duel import *
 from .command_server import start_command_server
 from .modloader import *
 from .disabled_mods import *
+from .data import *
+from . import builtin_commands
+from . import builtin_mods
 
 import os
 
